==> mastapy-14.0.0b2.tar.gz: mastapy-14.0.0b2/mastapy/_private/_internal/implicit/enum_with_selected_value/residual_stress_calculation_method.py <==
"""Implementations of 'EnumWithSelectedValue' in Python.

As Python does not have an implicit operator, this is the next
best solution for implementing these types properly.
"""
from __future__ import annotations

from enum import Enum
from typing import TYPE_CHECKING

from mastapy._private.gears.gear_designs.cylindrical import _1100
from mastapy._private._internal import mixins
from mastapy._private._internal.python_net import python_net_import

_ARRAY = python_net_import("System", "Array")
_ENUM_WITH_SELECTED_VALUE = python_net_import(
    "SMT.MastaAPI.Utility.Property", "EnumWithSelectedValue"
)

if TYPE_CHECKING:
    from typing import List, Type, Any, TypeVar

    Self = TypeVar(
        "Self", bound="EnumWithSelectedValue_ResidualStressCalculationMethod"
    )


__docformat__ = "restructuredtext en"
__all__ = ("EnumWithSelectedValue_ResidualStressCalculationMethod",)


class EnumWithSelectedValue_ResidualStressCalculationMethod(
    mixins.EnumWithSelectedValueMixin, Enum
):
    """EnumWithSelectedValue_ResidualStressCalculationMethod

    A specific implementation of 'EnumWithSelectedValue' for 'ResidualStressCalculationMethod' types.
    """

    __qualname__ = "ResidualStressCalculationMethod"

    @classmethod
    def wrapper_type(
        cls: "Type[EnumWithSelectedValue_ResidualStressCalculationMethod]",
    ) -> "Any":
        """Pythonnet type of this class.

        Note:
            This property is readonly.

        Returns:
            Any
        """
        return _ENUM_WITH_SELECTED_VALUE

    @classmethod
    def wrapped_type(
        cls: "Type[EnumWithSelectedValue_ResidualStressCalculationMethod]",
    ) -> "_1100.ResidualStressCalculationMethod":
        """Wrapped Pythonnet type of this class.

        Note:
            This property is readonly

        Returns:
            _1100.ResidualStressCalculationMethod
        """
        return _1100.ResidualStressCalculationMethod

    @classmethod
    def implicit_type(
        cls: "Type[EnumWithSelectedValue_ResidualStressCalculationMethod]",
    ) -> "Any":
        """Implicit Pythonnet type of this class.

        Note:
            This property is readonly.

        Returns:
            Any
        """
        return _1100.ResidualStressCalculationMethod.type_()

    @property
    def selected_value(self: "Self") -> "_1100.ResidualStressCalculationMethod":
        """mastapy._private.gears.gear_designs.cylindrical.ResidualStressCalculationMethod

        Note:
            This property is readonly.
        """
        return None

    @property
    def available_values(self: "Self") -> "List[_1100.ResidualStressCalculationMethod]":
        """List[mastapy._private.gears.gear_designs.cylindrical.ResidualStressCalculationMethod]

        Note:
            This property is readonly.
        """
        return None

==> mastapy-14.1.3.tar.gz: mastapy-14.1.3/mastapy/_private/_internal/implicit/enum_with_selected_value/residual_stress_calculation_method.py <==
"""Implementations of 'EnumWithSelectedValue' in Python.

As Python does not have an implicit operator, this is the next
best solution for implementing these types properly.
"""

from __future__ import annotations

from enum import Enum
from typing import TYPE_CHECKING

from mastapy._private._internal import mixins
from mastapy._private._internal.python_net import python_net_import
from mastapy._private.gears.gear_designs.cylindrical import _1109

_ARRAY = python_net_import("System", "Array")
_ENUM_WITH_SELECTED_VALUE = python_net_import(
    "SMT.MastaAPI.Utility.Property", "EnumWithSelectedValue"
)

if TYPE_CHECKING:
    from typing import Any, List, Type, TypeVar

    Self = TypeVar(
        "Self", bound="EnumWithSelectedValue_ResidualStressCalculationMethod"
    )


__docformat__ = "restructuredtext en"
__all__ = ("EnumWithSelectedValue_ResidualStressCalculationMethod",)


class EnumWithSelectedValue_ResidualStressCalculationMethod(
    mixins.EnumWithSelectedValueMixin, Enum
):
    """EnumWithSelectedValue_ResidualStressCalculationMethod

    A specific implementation of 'EnumWithSelectedValue' for 'ResidualStressCalculationMethod' types.
    """

    __qualname__ = "ResidualStressCalculationMethod"

    @classmethod
    def wrapper_type(
        cls: "Type[EnumWithSelectedValue_ResidualStressCalculationMethod]",
    ) -> "Any":
        """Pythonnet type of this class.

        Note:
            This property is readonly.

        Returns:
            Any
        """
        return _ENUM_WITH_SELECTED_VALUE

    @classmethod
    def wrapped_type(
        cls: "Type[EnumWithSelectedValue_ResidualStressCalculationMethod]",
    ) -> "_1109.ResidualStressCalculationMethod":
        """Wrapped Pythonnet type of this class.

        Note:
            This property is readonly

        Returns:
            _1109.ResidualStressCalculationMethod
        """
        return _1109.ResidualStressCalculationMethod

    @classmethod
    def implicit_type(
        cls: "Type[EnumWithSelectedValue_ResidualStressCalculationMethod]",
    ) -> "Any":
        """Implicit Pythonnet type of this class.

        Note:
            This property is readonly.

        Returns:
            Any
        """
        return _1109.ResidualStressCalculationMethod.type_()

    @property
    def selected_value(self: "Self") -> "_1109.ResidualStressCalculationMethod":
        """mastapy.gears.gear_designs.cylindrical.ResidualStressCalculationMethod

        Note:
            This property is readonly.
        """
        return None

    @property
    def available_values(self: "Self") -> "List[_1109.ResidualStressCalculationMethod]":
        """List[mastapy.gears.gear_designs.cylindrical.ResidualStressCalculationMethod]

        Note:
            This property is readonly.
        """
        return None
